@@ -17,8 +17,11 @@ def insertDataIntoDatabase(sql:str, params:list, connection):
     cursor = connection.cursor()
     try:
         cursor.execute(sql,params)
+        result = cursor.fetchall()
         connection.commit()
         cursor.close()
+        if len(result) > 0:
+            return result
         return None
     except Exception as e:
         connection.commit()
